# Big Local News Python SDK

This package provides a Big Local News Python API client.

## Tutorial
1. Install the `jupyterlab` and `bln` python packages:
```{bash}
pip install jupyterlab
pip install bln
```
2. Start jupyter lab:
```{bash}
jupyter notebook
```
3. Open the tutorial and follow along!
